@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = '0.2'
+__version__ = '0.3'
 
 
 class RoundHouseKick(Exception):
@@ -27,6 +27,22 @@ def assert_raises(excClass, callableObj, *args, **kwargs):
 def assert_equals(first, second, msg=None):
     pass
 
+assert_equal = assert_equals
+
 
 def assert_not_equals(first, second, msg=None):
     pass
+
+assert_not_equal = assert_not_equals
+
+
+def assert_almost_equals(first, second, places=7, msg=None):
+    pass
+
+assert_almost_equal = assert_almost_equals
+
+
+def assert_not_almost_equals(first, second, places=7, msg=None):
+    pass
+
+assert_not_almost_equal = assert_not_almost_equals
